@@ -6,9 +6,9 @@ from grebble_flow.transport.generated.sdk.v1 import processor_pb2_grpc
 from grebble_flow.transport.service.processor import ProcessorService
 
 
-def start_server(port):
+def start_server(port, max_workers=2):
     server = grpc.server(
-        futures.ThreadPoolExecutor(max_workers=10),
+        futures.ThreadPoolExecutor(max_workers=max_workers),
         options=[
             ("grpc.max_send_message_length", 50 * 1024 * 1024),
             ("grpc.max_receive_message_length", 50 * 1024 * 1024),
